.. _transports:

Transports
==========

GQL Transports are used to define how the connection is made with the backend.
We have different transports for different underlying protocols (http, websockets, ...)

.. toctree::
   :maxdepth: 2

   async_transports
   sync_transports
